==> swc-1.4.11.tar.gz: swc-1.4.11/crates/swc/tests/tsc-references/usingDeclarations.11.1.normal.js <==
//// [usingDeclarations.11.ts]
import { _ as _class_call_check } from "@swc/helpers/_/_class_call_check";
import { _ as _inherits } from "@swc/helpers/_/_inherits";
import { _ as _possible_constructor_return } from "@swc/helpers/_/_possible_constructor_return";
import { _ as _create_super } from "@swc/helpers/_/_create_super";
import { _ as _dispose } from "@swc/helpers/_/_dispose";
import { _ as _using } from "@swc/helpers/_/_using";
var A = function A() {
    "use strict";
    _class_call_check(this, A);
};
var C1 = /*#__PURE__*/ function(A) {
    "use strict";
    _inherits(C1, A);
    var _super = _create_super(C1);
    function C1() {
        _class_call_check(this, C1);
        var _this;
        try {
            var _stack = [];
            var x = _using(_stack, null);
            _this = _super.call(this);
        } catch (_) {
            var _error = _;
            var _hasError = true;
        } finally{
            _dispose(_stack, _error, _hasError);
        }
        return _possible_constructor_return(_this);
    }
    return C1;
}(A);
var C2 = /*#__PURE__*/ function(A) {
    "use strict";
    _inherits(C2, A);
    var _super = _create_super(C2);
    function C2() {
        _class_call_check(this, C2);
        var _this;
        try {
            var _stack = [];
            _this = _super.call(this);
            var x = _using(_stack, null);
        } catch (_) {
            var _error = _;
            var _hasError = true;
        } finally{
            _dispose(_stack, _error, _hasError);
        }
        return _possible_constructor_return(_this);
    }
    return C2;
}(A);
var C3 = /*#__PURE__*/ function(A) {
    "use strict";
    _inherits(C3, A);
    var _super = _create_super(C3);
    function C3() {
        _class_call_check(this, C3);
        var _this;
        try {
            var _stack = [];
            var x = _using(_stack, null);
            _this = _super.call(this);
            _this.y = 1;
        } catch (_) {
            var _error = _;
            var _hasError = true;
        } finally{
            _dispose(_stack, _error, _hasError);
        }
        return _possible_constructor_return(_this);
    }
    return C3;
}(A);
var C4 = /*#__PURE__*/ function(A) {
    "use strict";
    _inherits(C4, A);
    var _super = _create_super(C4);
    function C4(y) {
        _class_call_check(this, C4);
        var _this;
        try {
            var _stack = [];
            var x = _using(_stack, null);
            _this = _super.call(this);
            _this.y = y;
        } catch (_) {
            var _error = _;
            var _hasError = true;
        } finally{
            _dispose(_stack, _error, _hasError);
        }
        return _possible_constructor_return(_this);
    }
    return C4;
}(A);
var C5 = /*#__PURE__*/ function(A) {
    "use strict";
    _inherits(C5, A);
    var _super = _create_super(C5);
    function C5(y) {
        _class_call_check(this, C5);
        var _this;
        try {
            var _stack = [];
            var x = _using(_stack, null);
            _this = _super.call(this);
            _this.y = y;
            _this.z = 1;
        } catch (_) {
            var _error = _;
            var _hasError = true;
        } finally{
            _dispose(_stack, _error, _hasError);
        }
        return _possible_constructor_return(_this);
    }
    return C5;
}(A);

==> swc-1.5.0.tar.gz: swc-1.5.0/crates/swc/tests/tsc-references/usingDeclarations.11.1.normal.js <==
//// [usingDeclarations.11.ts]
import { _ as _class_call_check } from "@swc/helpers/_/_class_call_check";
import { _ as _inherits } from "@swc/helpers/_/_inherits";
import { _ as _possible_constructor_return } from "@swc/helpers/_/_possible_constructor_return";
import { _ as _create_super } from "@swc/helpers/_/_create_super";
import { _ as _using_ctx } from "@swc/helpers/_/_using_ctx";
var A = function A() {
    "use strict";
    _class_call_check(this, A);
};
var C1 = /*#__PURE__*/ function(A) {
    "use strict";
    _inherits(C1, A);
    var _super = _create_super(C1);
    function C1() {
        _class_call_check(this, C1);
        var _this;
        try {
            var _usingCtx = _using_ctx();
            var x = _usingCtx.u(null);
            _this = _super.call(this);
        } catch (_) {
            _usingCtx.e = _;
        } finally{
            _usingCtx.d();
        }
        return _possible_constructor_return(_this);
    }
    return C1;
}(A);
var C2 = /*#__PURE__*/ function(A) {
    "use strict";
    _inherits(C2, A);
    var _super = _create_super(C2);
    function C2() {
        _class_call_check(this, C2);
        var _this;
        try {
            var _usingCtx = _using_ctx();
            _this = _super.call(this);
            var x = _usingCtx.u(null);
        } catch (_) {
            _usingCtx.e = _;
        } finally{
            _usingCtx.d();
        }
        return _possible_constructor_return(_this);
    }
    return C2;
}(A);
var C3 = /*#__PURE__*/ function(A) {
    "use strict";
    _inherits(C3, A);
    var _super = _create_super(C3);
    function C3() {
        _class_call_check(this, C3);
        var _this;
        try {
            var _usingCtx = _using_ctx();
            var x = _usingCtx.u(null);
            _this = _super.call(this);
            _this.y = 1;
        } catch (_) {
            _usingCtx.e = _;
        } finally{
            _usingCtx.d();
        }
        return _possible_constructor_return(_this);
    }
    return C3;
}(A);
var C4 = /*#__PURE__*/ function(A) {
    "use strict";
    _inherits(C4, A);
    var _super = _create_super(C4);
    function C4(y) {
        _class_call_check(this, C4);
        var _this;
        try {
            var _usingCtx = _using_ctx();
            var x = _usingCtx.u(null);
            _this = _super.call(this);
            _this.y = y;
        } catch (_) {
            _usingCtx.e = _;
        } finally{
            _usingCtx.d();
        }
        return _possible_constructor_return(_this);
    }
    return C4;
}(A);
var C5 = /*#__PURE__*/ function(A) {
    "use strict";
    _inherits(C5, A);
    var _super = _create_super(C5);
    function C5(y) {
        _class_call_check(this, C5);
        var _this;
        try {
            var _usingCtx = _using_ctx();
            var x = _usingCtx.u(null);
            _this = _super.call(this);
            _this.y = y;
            _this.z = 1;
        } catch (_) {
            _usingCtx.e = _;
        } finally{
            _usingCtx.d();
        }
        return _possible_constructor_return(_this);
    }
    return C5;
}(A);
